@@ -62,7 +62,7 @@ class UserMediaImageForm(forms.ModelForm):
     """Form that allows to create or update an `UserMediaImage` object."""
     class Meta:
         model = UserMediaImage
-        exclude = ('user', 'content_type', 'object_id')
+        fields = ('image',)
 
     def __init__(self, user, content_type, object_id, *args, **kwargs):
         self.user = user
@@ -70,6 +70,21 @@ class UserMediaImageForm(forms.ModelForm):
         self.object_id = object_id
         super(UserMediaImageForm, self).__init__(*args, **kwargs)
 
+    def clean_image(self):
+        """
+        It seems like in Django 1.5 something has changed.
+
+        When Django tries to validate the form, it checks if the generated
+        filename fit into the max_length. But at this point, self.instance.user
+        is not yet set so our filename generation function cannot create
+        the new file path because it needs the user id. Setting
+        self.instance.user at this point seems to work as a workaround.
+
+        """
+        self.instance.user = self.user
+        data = self.cleaned_data.get('image')
+        return data
+
     def save(self, *args, **kwargs):
         self.instance.user = self.user
         self.instance.content_type = self.content_type
